# coding: utf-8

"""
    Analysis

    Analyse content using Linked Data and Knowledge Graphs.

    The version of the OpenAPI document: 1.0
    Contact: hello@wordlift.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from wordlift_client.models.response1 import Response1

class TestResponse1(unittest.TestCase):
    """Response1 unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> Response1:
        """Test Response1
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `Response1`
        """
        model = Response1()
        if include_optional:
            return Response1(
                items = [
                    wordlift_client.models.event.Event(
                        source = '', 
                        args = wordlift_client.models.args.args(), 
                        url = '', 
                        recorded_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        account_id = 56, )
                    ],
                var_self = '',
                next = '',
                prev = '',
                last = '',
                first = ''
            )
        else:
            return Response1(
        )
        """

    def testResponse1(self):
        """Test Response1"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
