# coding: utf-8

# flake8: noqa
"""
    WordLift Fact-Checking API

    API for semi-automated fact-checking. Returns schema.org/ClaimReview markup. This markup is structured data that contains information about the fact check -- for example, what was the claim being assessed, who made the claim, what was the verdict.

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


# import models into model package
from wordlift_client.models.account import Account
from wordlift_client.models.account_info import AccountInfo
from wordlift_client.models.account_subscription import AccountSubscription
from wordlift_client.models.active_account import ActiveAccount
from wordlift_client.models.add_on_configuration import AddOnConfiguration
from wordlift_client.models.analyses_request import AnalysesRequest
from wordlift_client.models.analyses_response import AnalysesResponse
from wordlift_client.models.analyses_response_item import AnalysesResponseItem
from wordlift_client.models.analytics_import_request import AnalyticsImportRequest
from wordlift_client.models.annotation import Annotation
from wordlift_client.models.autocomplete_result import AutocompleteResult
from wordlift_client.models.batch_request import BatchRequest
from wordlift_client.models.botify_crawl_import_request import BotifyCrawlImportRequest
from wordlift_client.models.build_authorize_uri_request import BuildAuthorizeUriRequest
from wordlift_client.models.build_authorize_uri_response import BuildAuthorizeUriResponse
from wordlift_client.models.classification_request import ClassificationRequest
from wordlift_client.models.classification_response import ClassificationResponse
from wordlift_client.models.completion_request import CompletionRequest
from wordlift_client.models.content_expansion_request import ContentExpansionRequest
from wordlift_client.models.content_expansion_response import ContentExpansionResponse
from wordlift_client.models.content_generation import ContentGeneration
from wordlift_client.models.content_generation_request import ContentGenerationRequest
from wordlift_client.models.content_generation_stats import ContentGenerationStats
from wordlift_client.models.create_embeddings_input import CreateEmbeddingsInput
from wordlift_client.models.create_seo_score200_response import CreateSEOScore200Response
from wordlift_client.models.create_seo_score_request import CreateSEOScoreRequest
from wordlift_client.models.diagnostic_plugin import DiagnosticPlugin
from wordlift_client.models.diagnostic_plugin_request import DiagnosticPluginRequest
from wordlift_client.models.domain_validation_request import DomainValidationRequest
from wordlift_client.models.embedding_request import EmbeddingRequest
from wordlift_client.models.entity import Entity
from wordlift_client.models.entity1 import Entity1
from wordlift_client.models.entity_gap_request import EntityGapRequest
from wordlift_client.models.entity_match import EntityMatch
from wordlift_client.models.entity_patch_request import EntityPatchRequest
from wordlift_client.models.event import Event
from wordlift_client.models.exchange_auth_code_request import ExchangeAuthCodeRequest
from wordlift_client.models.exchange_auth_code_response import ExchangeAuthCodeResponse
from wordlift_client.models.filter import Filter
from wordlift_client.models.filter_value import FilterValue
from wordlift_client.models.generate_sitemap200_response import GenerateSitemap200Response
from wordlift_client.models.generate_sitemap_request import GenerateSitemapRequest
from wordlift_client.models.graphql_request import GraphqlRequest
from wordlift_client.models.html import Html
from wordlift_client.models.image import Image
from wordlift_client.models.include_exclude import IncludeExclude
from wordlift_client.models.include_exclude_request import IncludeExcludeRequest
from wordlift_client.models.inspect_response import InspectResponse
from wordlift_client.models.level_enum import LevelEnum
from wordlift_client.models.longtail_response import LongtailResponse
from wordlift_client.models.merchant import Merchant
from wordlift_client.models.merchant_entry import MerchantEntry
from wordlift_client.models.merchant_request import MerchantRequest
from wordlift_client.models.merchant_sync import MerchantSync
from wordlift_client.models.merchant_view import MerchantView
from wordlift_client.models.model import Model
from wordlift_client.models.model_field import ModelField
from wordlift_client.models.network_account_info import NetworkAccountInfo
from wordlift_client.models.node_request import NodeRequest
from wordlift_client.models.o_auth2_authorized_client import OAuth2AuthorizedClient
from wordlift_client.models.o_auth2_authorized_client_request import OAuth2AuthorizedClientRequest
from wordlift_client.models.page_active_account import PageActiveAccount
from wordlift_client.models.page_add_on_configuration import PageAddOnConfiguration
from wordlift_client.models.page_content_generation import PageContentGeneration
from wordlift_client.models.page_field import PageField
from wordlift_client.models.page_merchant_entry import PageMerchantEntry
from wordlift_client.models.page_merchant_sync import PageMerchantSync
from wordlift_client.models.page_merchant_view import PageMerchantView
from wordlift_client.models.page_model import PageModel
from wordlift_client.models.page_o_auth2_authorized_client import PageOAuth2AuthorizedClient
from wordlift_client.models.page_platform_limit import PagePlatformLimit
from wordlift_client.models.page_preset import PagePreset
from wordlift_client.models.page_record import PageRecord
from wordlift_client.models.page_rule import PageRule
from wordlift_client.models.page_vector_search_query_response_item import PageVectorSearchQueryResponseItem
from wordlift_client.models.page_vector_search_question_response_item import PageVectorSearchQuestionResponseItem
from wordlift_client.models.page_website import PageWebsite
from wordlift_client.models.page_website_search import PageWebsiteSearch
from wordlift_client.models.page_with_limits import PageWithLimits
from wordlift_client.models.page_word import PageWord
from wordlift_client.models.platform_limit import PlatformLimit
from wordlift_client.models.platform_limit_request import PlatformLimitRequest
from wordlift_client.models.preset import Preset
from wordlift_client.models.problem_detail import ProblemDetail
from wordlift_client.models.project_type import ProjectType
from wordlift_client.models.properties import Properties
from wordlift_client.models.properties1 import Properties1
from wordlift_client.models.question_and_answer import QuestionAndAnswer
from wordlift_client.models.question_and_answer_request import QuestionAndAnswerRequest
from wordlift_client.models.rank_entities import RankEntities
from wordlift_client.models.record import Record
from wordlift_client.models.render_request import RenderRequest
from wordlift_client.models.request import Request
from wordlift_client.models.request1 import Request1
from wordlift_client.models.request2 import Request2
from wordlift_client.models.request3 import Request3
from wordlift_client.models.response import Response
from wordlift_client.models.response1 import Response1
from wordlift_client.models.response2 import Response2
from wordlift_client.models.rule import Rule
from wordlift_client.models.rule_request import RuleRequest
from wordlift_client.models.scope import Scope
from wordlift_client.models.sitemap_import_request import SitemapImportRequest
from wordlift_client.models.smart_content import SmartContent
from wordlift_client.models.smart_content_request import SmartContentRequest
from wordlift_client.models.submit_fact_check200_response import SubmitFactCheck200Response
from wordlift_client.models.submit_fact_check_request import SubmitFactCheckRequest
from wordlift_client.models.topic import Topic
from wordlift_client.models.update_account_request import UpdateAccountRequest
from wordlift_client.models.update_question_and_answer_request import UpdateQuestionAndAnswerRequest
from wordlift_client.models.update_record_request import UpdateRecordRequest
from wordlift_client.models.update_records_request import UpdateRecordsRequest
from wordlift_client.models.validation_fix import ValidationFix
from wordlift_client.models.validation_result import ValidationResult
from wordlift_client.models.validation_type_enum import ValidationTypeEnum
from wordlift_client.models.vector_search_query_request import VectorSearchQueryRequest
from wordlift_client.models.vector_search_query_response_item import VectorSearchQueryResponseItem
from wordlift_client.models.vector_search_question_request import VectorSearchQuestionRequest
from wordlift_client.models.vector_search_question_response_item import VectorSearchQuestionResponseItem
from wordlift_client.models.web_async import WebAsync
from wordlift_client.models.web_page import WebPage
from wordlift_client.models.webpage_properties import WebpageProperties
from wordlift_client.models.website import Website
from wordlift_client.models.website_search import WebsiteSearch
from wordlift_client.models.what_operand_lhs import WhatOperandLhs
from wordlift_client.models.what_operator import WhatOperator
from wordlift_client.models.when_operator import WhenOperator
from wordlift_client.models.with_limits import WithLimits
from wordlift_client.models.word import Word
from wordlift_client.models.word_repetition_data import WordRepetitionData
from wordlift_client.models.word_request import WordRequest
