# coding: utf-8

"""
    Analysis

    Analyse content using Linked Data and Knowledge Graphs.

    The version of the OpenAPI document: 1.0
    Contact: hello@wordlift.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from wordlift_client.api.google_search_console_o_auth2_api import GoogleSearchConsoleOAuth2Api


class TestGoogleSearchConsoleOAuth2Api(unittest.TestCase):
    """GoogleSearchConsoleOAuth2Api unit test stubs"""

    def setUp(self) -> None:
        self.api = GoogleSearchConsoleOAuth2Api()

    def tearDown(self) -> None:
        pass

    def test_create_auth_code_exchange(self) -> None:
        """Test case for create_auth_code_exchange

        Get an Access Code
        """
        pass

    def test_create_authorize_uri(self) -> None:
        """Test case for create_authorize_uri

        Create an Authorization URI
        """
        pass


if __name__ == '__main__':
    unittest.main()
