# coding: utf-8

"""
    Analysis

    Analyse content using Linked Data and Knowledge Graphs.

    The version of the OpenAPI document: 1.0
    Contact: hello@wordlift.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from wordlift_client.api.vector_search_nodes_api import VectorSearchNodesApi


class TestVectorSearchNodesApi(unittest.TestCase):
    """VectorSearchNodesApi unit test stubs"""

    def setUp(self) -> None:
        self.api = VectorSearchNodesApi()

    def tearDown(self) -> None:
        pass

    def test_update_nodes_collection(self) -> None:
        """Test case for update_nodes_collection

        Update
        """
        pass


if __name__ == '__main__':
    unittest.main()
